<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Stufe %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Kein Cover</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Bitte die neue Erweiterung eingeben:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Neue Erweiterung anlegen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Verzeichnis mit Filmen</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Das Verzeichnis muß existieren, und MythVideo Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Anfangs-Kindersicherungs-Level</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Höchster</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Niedrigster</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>MythVideo startet mit diesem &apos;Level&apos;. Videos mit gleichem oder niedrigerem Level werden angezeigt. Die Kindersicherungs-PIN sollte gesetzt werden, um das Ändern des Default-Levels einzuschränken.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>Kindersicherungs-PIN</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Falls gesetzt, können Sie nicht mehr zu diesem Menü zurückkehren und die PIN neu setzen, ohne die aktuelle PIN einzugeben. Sie wurden gewarnt.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Unbekannte Dateitypen anzeigen</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Wenn gesetzt, so werden alle Dateien innerhalb des MythVideo-Verzeichnisses und darunter angezeigt, falls ihre Erweiterungen nicht explizit auf &apos;Ignorieren&apos; gesetzt sind.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>Dateien in Videoliste anzeigen</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Falls gesetzt, so werden im Videolisten-Menü alle relevanten Dateien im MythVideo Verzeichnis und darunter, unabhängig davon ob sie eingelesen wurden oder nicht, angezeigt.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Grundeinstellungen</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Kindersicherungs-PIN:</translation>
    </message>
    <message>
        <source>Searching for video files</source>
        <translation>Suche nach Videodateien</translation>
    </message>
    <message>
        <source>Updating video database</source>
        <translation>Aktualisiere Videodatenbank</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Kein Cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nicht vorhanden</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>Unbewertet</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation>Unbekannte Altersfreigabe</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Abspielbefehl</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Neue Videos freigeben</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>Falls gesetzt, werden neue Dateien im Videomanager als freigegeben markiert und erscheinen im &apos;Browse&apos; Menü.</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Neue Kategorie</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation>Diese PIN schützt bestimmte Videos vor unbefugtem Zugriff. Für eine einfachere Handhabung verwenden Sie für diesen Code bitte nur Ziffern.</translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Befehl für die Filmsuche</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>Dieses Programm muß für MythVideo ausführbar sein.</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Befehl für die Titelbildsuche</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Befehl für die Suche nach Filminfos</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Verzeichnis für Titelbilder</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>Dieses Verzeichnis muß existieren und MythVideo Schreib-/Leserechte dafür besitzen.</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Video Manager</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>Konnte Titelbild nicht finden</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>Für diesen Film existiert ein Titelbild aber MythVideo konnte es nicht in einer angemessenen Zeitspanne laden.
</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Standardansicht</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerie</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Browser</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Übersicht</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Aggressive Kindersicherung</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation>Dieser Befehl wird für alle Dateien verwendet, für deren Erweiterung nichts anderes festgelegt wurde. Sie können auch den Namen eines MythTV Plugins eingeben, z.B. &apos;Internal&apos;.</translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Wieviele Zeilen anzeigen</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Wieviele Spalten anzeigen</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Titel unter den Miniaturbildern zeigen</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Falls gesetzt, werden durch den zusätzlichen Text die Miniaturbilder kleiner.</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Seitenverhältnis der Miniaturbilder beibehalten</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Falls gesetzt, behalten die Miniaturbilder ihr Seitenverhältnis bei. Ansonsten werden sie passend zum Hintergrundsymbol skaliert.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Videogalerie</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>Die Standardansicht für MythVideo. Andere Ansichten können durch drücken der &apos;MENU&apos;-Taste im Popup-Fenster ausgewählt werden.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Regisseur:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Freigabe:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Kindersicherungs-Level:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Listbar:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Handlung:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Cover-Datei:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>IMDB-Nr.:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>Hole Daten...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ suche nach ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Eingabe IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>Lade...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Keine Videos gefunden</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Regie:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Datei:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Abspieler:</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>MythVideo-Dateiverknüpfungen</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Erweiterung:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Standard-Abspieler:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignoriere:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Video-Informationen bearbeiten</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Kindersicherungs-Level:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Anschließend abspielen:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Beim browsen berücksichtigen:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Cover-Bild:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Spezielles Abspielkommando:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/pfad/zum/bild.jpg</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>PL</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategorie:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filtert die Videoliste</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Kategorie :</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genre :</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Land :</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>Jahr :</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Laufzeit :</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Bewertung :</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Durchsuchen :</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Sortierung :</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation>Kein Video</translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>SELECT: Bearbeiten</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Laufzeit</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Bewertung</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Aktionenmenü</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Auf/Ab, Seite Auf/Ab: Browse   MENÜ: Optionen   INFO: Aktionenmenü</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Anschließend abspielen:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 von %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Keine Videos</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation>Keine Altersfreigabe vorhanden.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Film ansehen</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vollst. Beschreibung zeigen</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Anzeige filtern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Zur Browse-Ansicht wechseln</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Zur Galerie-Ansicht wechseln</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Zur Übersichts-Ansicht wechseln</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Aktion wählen</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>Kindersicherungs-PIN:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Ergebnis für diesen Filter: %1 Video(s)</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Ergebnis für diesen Filter: Keine Videos</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Als Standard abspeichern</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Anzeige filtern</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Film ansehen</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vollst. Beschreibung zeigen</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Einzelheiten zeigen</translation>
    </message>
    <message>
        <source>Plain View</source>
        <translation>Einfache Ansicht</translation>
    </message>
    <message>
        <source>Folder View</source>
        <translation>Verzeichnisansicht</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Manuelle Eingabe der IMDB-Nr.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Kein Cover</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nicht vorhanden</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>Unbewertet</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>löschen fehlgeschlagen</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Aktion wählen:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Metadaten bearbeiten</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Bei IMDB suchen</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Metadaten zurücksetzen</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Video entfernen</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Anzeige filtern</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Diese Datei löschen?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation>Keine Altersfreigabe vorhanden.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuten</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation>Kindersicherungs-PIN:</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Keine Dateien gefunden</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Aktion wählen</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Film ansehen</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>vollst. Beschreibung zeigen</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Anzeige filtern</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Zur Browse-Ansicht wechseln</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Zur Galerie-Ansicht wechseln</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
